ModuleRegistry class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

all Iterable<ScopedModule>
no setter

Static Methods

attachChannels(BinaryMessenger messenger) → void
get(String moduleId) ScopedModule?
notifyCleared() Future<void>
notifyConfigurationUpdated({String? locale, String? theme}) Future<void>
notifyInitialized() Future<void>
register(ScopedModule module) → void
unregister(String moduleId) → void