QuickPayConfig class

Constructors

QuickPayConfig({required String merchantId, required QuickPayEnvironment environment, String? merchantName, String? merchantUrl, QuickPayLocale locale = QuickPayLocale.system, QuickPayThemeColorScheme theme = QuickPayThemeColorScheme.system, bool enableLogging = false})
Creates a configuration for Yandex Quick Payment SDK.
const

Properties

enableLogging → bool
final
environment → QuickPayEnvironment
final
hashCode → int
The hash code for this object.
no setterinherited
locale → QuickPayLocale
final
merchantId → String
final
merchantName → String?
final
merchantUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → QuickPayThemeColorScheme
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited