yandex_quick_pay library

Classes

ModuleRegistry
QuickPayConfig
QuickPayFailure
Payment failed.
QuickPaymentStateListener
Listener for quick payment state changes.
QuickPayResult
Base class for the result of a quick payment operation.
QuickPaySuccess
Payment completed successfully.
QuickPayWidgetExpandStateListener
Warning: This listener is not exported from the public barrel file. Import directly: import 'package:yandex_pay_quickpay/src/quick_pay_widget_expand_state_listener.dart'; Exclusive Merchant API. Usage must be coordinated with the Yandex Pay team.
ScopedChannels
ScopedModule
YandexActivePaymentMethodBadge
Widget that displays the active payment method badge.
YandexExpandablePaymentMethodsWidget
Exclusive Merchant API. Usage must be coordinated with the Yandex Pay team.
YandexPaymentMethodsWidget
Widget that displays available payment methods and allows managing quick payment settings.
YandexQuickPay
YPay
YPayDeeplinkHandler
YPayModuleDescriptor
YQuickPay
YQuickPaymentStateListener

Enums

QuickPayEnvironment
QuickPayLocale
QuickPayThemeColorScheme
QuickPayWidgetExpandState
Exclusive Merchant API. Usage must be coordinated with the Yandex Pay team. Available via import 'package:yandex_pay_quickpay/yandex_pay_quickpay.dart';
YPayEnvironment
YPayLocale
YPayTheme

Functions

quickPayModule({required String merchantId, String? merchantName, String? merchantUrl, QuickPayEnvironment environment = QuickPayEnvironment.sandbox, QuickPayLocale? locale, QuickPayThemeColorScheme? theme, bool isActivatedByDefault = true, bool enableLogging = false, YQuickPaymentStateListener? stateListener}) YPayModuleDescriptor