YandexQuickPay class
- Annotations
-
- @Deprecated('Use YPay.initialize(modules: [quickPayModule(...)]) and YQuickPay.instance instead. ' 'YandexQuickPay will be removed in a future major release.')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableQuickPayment(
) → Future< bool> -
enableQuickPayment(
) → Future< bool> -
Note: the
isOnboardingShownAfterAuthflag is only available via the newYQuickPay.instance.enableQuickPayment(...)API. The shim uses the current default (true). -
getCPQR(
String merchantPayload) → Future< String> -
getPaymentSessionId(
) → Future< String> -
handleOpenURL(
String url) → Future< bool> -
handleUserActivity(
String url) → Future< bool> -
hideActivePaymentMethod(
) → Future< void> -
initUi(
) → Future< void> -
isQuickPaymentEnabled(
) → Future< bool> -
login(
) → Future< bool> -
logout(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showActivePaymentMethod(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → YandexQuickPay
-
no setter
Static Methods
-
dispose(
) → Future< void> -
initialize(
{required QuickPayConfig config, required QuickPaymentStateListener listener}) → Future< void>